@@ -2,14 +2,16 @@
 
 # Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of python-djvulibre.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# python-djvulibre is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# python-djvulibre is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 import collections
 import codecs
@@ -24,11 +26,37 @@ try:
 except ImportError:
     cpickle = None
 
-from djvu.sexpr import *
-from djvu.sexpr import __version__
-from djvu.sexpr import _ExpressionIO
+from djvu.sexpr import (
+    Expression,
+    ExpressionSyntaxError,
+    Symbol,
+    _ExpressionIO,
+    __version__,
+)
 
-from common import *
+from tools import (
+    SkipTest,
+    assert_equal,
+    assert_false,
+    assert_in,
+    assert_is,
+    assert_is_instance,
+    assert_less,
+    assert_list_equal,
+    assert_not_equal,
+    assert_not_in,
+    assert_raises,
+    assert_raises_str,
+    assert_repr,
+    wildcard_import,
+    # Python 2/3 compat:
+    StringIO,
+    b,
+    long,
+    py3k,
+    u,
+    unicode,
+)
 
 def assert_pickle_equal(obj):
     for pickle_module in pickle, cpickle:
@@ -41,27 +69,72 @@ def assert_pickle_equal(obj):
 
 class test_int_expressions():
 
-    def test_short(self):
-        x = Expression(3)
-        assert_repr(x, 'Expression(3)')
+    def t(self, n, x=None):
+        if x is None:
+            x = Expression(n)
         assert_is(x, Expression(x))
-        assert_equal(x.value, 3)
-        assert_equal(x.lvalue, 3)
-        assert_equal(str(x), '3')
-        assert_repr(x, repr(Expression.from_string(str(x))))
-        assert_equal(int(x), 3)
-        if not py3k:
-            long_x = long(x)
-            assert_equal(type(long_x), long)
-            assert_equal(long_x, L(3))
-        assert_equal(x, Expression(3))
-        assert_not_equal(x, Expression(-3))
-        assert_equal(hash(x), x.value)
-        assert_not_equal(x, 3)
+        # __repr__():
+        assert_repr(x, 'Expression({n})'.format(n=int(n)))
+        # value:
+        v = x.value
+        assert_equal(type(v), int)
+        assert_equal(v, n)
+        # lvalue:
+        v = x.lvalue
+        assert_equal(type(v), int)
+        assert_equal(v, n)
+        # __int__():
+        i = int(x)
+        assert_equal(type(i), int)
+        assert_equal(i, n)
+        # __long__():
+        i = long(x)
+        assert_equal(type(i), long)
+        assert_equal(i, n)
+        # __float__():
+        i = float(x)
+        assert_equal(type(i), float)
+        assert_equal(i, n)
+        # __str__():
+        s = str(x)
+        assert_equal(s, str(n))
+        # __unicode__():
+        s = unicode(x)
+        assert_equal(s, str(n))
+        # __eq__(), __ne__():
+        assert_equal(x, Expression(n))
+        assert_not_equal(x, n)
+        assert_not_equal(x, Expression(n + 37))
+        # __hash__():
+        assert_equal(hash(x), n)
+        # __bool__() / __nonzero__():
+        obj = object()
+        if n:
+            assert_is(x and obj, obj)
+            assert_is(x or obj, x)
+        else:
+            assert_is(x and obj, x)
+            assert_is(x or obj, obj)
+        # pickle:
+        assert_pickle_equal(x)
+
+    def test_int(self):
+        self.t(42)
+
+    def test_parse(self):
+        self.t(42, Expression.from_string('42'))
+
+    def test_unpickle(self):
+        # pickle as generated by python-djvulibre 0.3.3:
+        p = b("cdjvu.sexpr\n_expression_from_string\np0\n(S'42'\np1\ntp2\nRp3\n.")
+        x = pickle.loads(p)
+        self.t(42, x)
+
+    def test_0(self):
+        self.t(0)
 
     def test_long(self):
-        x = Expression(L(42))
-        assert_repr(x, 'Expression(42)')
+        self.t(long(42))
 
     def test_limits(self):
         assert_equal(Expression((1 << 29) - 1).value, (1 << 29) - 1)
@@ -71,14 +144,6 @@ class test_int_expressions():
         with assert_raises_str(ValueError, 'value not in range(-2 ** 29, 2 ** 29)'):
             Expression((-1 << 29) - 1)
 
-    def test_bool(self):
-        assert_equal(Expression(1) and 42, 42)
-        assert_equal(Expression(0) or 42, 42)
-
-    def test_pickle(self):
-        x = Expression(42)
-        assert_pickle_equal(x)
-
 class test_float_expressions():
 
     # TODO: float expressions are not implemented yet
@@ -91,26 +156,32 @@ class test_float_expressions():
 
 class test_symbols():
 
-    def t(self, name):
+    def t(self, name, sname=None):
+        if sname is None:
+            sname = name
+        if py3k:
+            [uname, bname] = [sname, sname.encode('UTF-8')]
+        else:
+            [uname, bname] = [sname.decode('UTF-8'), sname]
         symbol = Symbol(name)
         assert_equal(type(symbol), Symbol)
         assert_equal(symbol, Symbol(name))
         assert_is(symbol, Symbol(name))
-        if py3k:
-            assert_equal(str(symbol), name)
-        else:
-            assert_equal(str(symbol), name.encode('UTF-8'))
-            assert_equal(unicode(symbol), name)
-        assert_not_equal(symbol, name)
-        assert_not_equal(symbol, name.encode('UTF-8'))
-        assert_equal(hash(symbol), hash(name.encode('UTF-8')))
+        assert_equal(str(symbol), sname)
+        assert_equal(unicode(symbol), uname)
+        assert_not_equal(symbol, bname)
+        assert_not_equal(symbol, uname)
+        assert_equal(hash(symbol), hash(bname))
         assert_pickle_equal(symbol)
+        return symbol
 
     def test_ascii(self):
         self.t('eggs')
 
     def test_nonascii(self):
-        self.t(u('ветчина'))
+        x = self.t(b('ветчина'), 'ветчина')
+        y = self.t(u('ветчина'), 'ветчина')
+        assert x is y
 
     def test_inequality(self):
         assert_less(
@@ -118,19 +189,55 @@ class test_symbols():
             Symbol('ham'),
         )
 
-def test_expressions():
-    x = Expression(Symbol('eggs'))
-    assert_repr(x, "Expression(Symbol('eggs'))")
-    assert_is(x, Expression(x))
-    assert_equal(x.value, Symbol('eggs'))
-    assert_equal(x.lvalue, Symbol('eggs'))
-    assert_equal(str(x), 'eggs')
-    assert_repr(x, repr(Expression.from_string(str(x))))
-    assert_equal(x, Expression(Symbol('eggs')))
-    assert_not_equal(x, Expression('eggs'))
-    assert_not_equal(x, Symbol('eggs'))
-    assert_equal(hash(x), hash('eggs'))
-    assert_pickle_equal(x)
+class test_symbol_expressions():
+
+    def t(self, name, sname):
+        if sname is None:
+            sname = name
+        if py3k:
+            [uname, bname] = [sname, sname.encode('UTF-8')]
+        else:
+            [uname, bname] = [sname.decode('UTF-8'), sname]
+        sym = Symbol(name)
+        x = Expression(sym)
+        assert_is(x, Expression(x))
+        # __repr__(x)
+        assert_repr(x, 'Expression({sym!r})'.format(sym=sym))
+        # value:
+        v = x.value
+        assert_equal(type(v), Symbol)
+        assert_equal(v, sym)
+        # lvalue:
+        v = x.lvalue
+        assert_equal(type(v), Symbol)
+        assert_equal(v, sym)
+        # __str__():
+        assert_equal(str(x), sname)
+        assert_repr(x, repr(Expression.from_string(sname)))
+        # __unicode__():
+        assert_equal(unicode(x), uname)
+        assert_repr(x, repr(Expression.from_string(uname)))
+        # __eq__(), __ne__():
+        assert_equal(x, Expression(sym))
+        assert_not_equal(x, Expression(name))
+        assert_not_equal(x, sym)
+        # __hash__():
+        assert_equal(
+            hash(x),
+            hash(bname.strip(b('|')))
+        )
+        # pickle:
+        assert_pickle_equal(x)
+        return x
+
+    def test_ascii(self):
+        self.t('eggs', 'eggs')
+
+    def test_nonascii(self):
+        x = self.t(b('ветчина'), '|ветчина|')
+        y = self.t(u('ветчина'), '|ветчина|')
+        assert_equal(x, y)
+        assert_equal(hash(x), hash(y))
 
 def test_string_expressions():
     x = Expression('eggs')
@@ -446,7 +553,7 @@ class test_expression_parser_ascii():
     expr = '(eggs) (ham)'
     repr = ["Expression([Symbol('eggs')])", "Expression([Symbol('ham')])"]
 
-    def _test_fp(self, fp):
+    def t(self, fp):
         def read():
             return Expression.from_stream(fp)
         x = read()
@@ -458,11 +565,11 @@ class test_expression_parser_ascii():
 
     def test_stringio(self):
         fp = StringIO(self.expr)
-        self._test_fp(fp)
+        self.t(fp)
 
     def test_bytesio(self):
         fp = io.BytesIO(b(self.expr))
-        self._test_fp(fp)
+        self.t(fp)
 
     def test_file_io_text(self):
         if py3k:
@@ -473,21 +580,21 @@ class test_expression_parser_ascii():
             fp.write(self.expr)
             fp.flush()
             fp.seek(0)
-            self._test_fp(fp)
+            self.t(fp)
 
     def test_codecs_io(self):
         with tempfile.NamedTemporaryFile(mode='w+b') as bfp:
             with codecs.open(bfp.name, mode='w+', encoding='UTF-16-LE') as fp:
                 fp.write(u(self.expr))
                 fp.seek(0)
-                self._test_fp(fp)
+                self.t(fp)
 
     def test_file_io_binary(self):
         with tempfile.TemporaryFile(mode='w+b') as fp:
             fp.write(b(self.expr))
             fp.flush()
             fp.seek(0)
-            self._test_fp(fp)
+            self.t(fp)
 
 class test_expression_parser_nonascii(test_expression_parser_ascii):
 
@@ -529,6 +636,13 @@ class test_expression_writer():
         fp = File()
         expr.print_into(fp)
 
+    def test_escape_unicode_type(self):
+        expr = Expression(23)
+        fp = StringIO()
+        for v in True, False, 1, 0, 'yes', '':
+            expr.print_into(fp, escape_unicode=v)
+            expr.as_string(escape_unicode=v)
+
 class test_expression_writer_ascii():
 
     expr = Expression([Symbol('eggs'), Symbol('ham')])
@@ -613,4 +727,19 @@ class test_expression_writer_nonascii(test_expression_writer_ascii):
 def test_version():
     assert_is_instance(__version__, str)
 
+def test_wildcard_import():
+    ns = wildcard_import('djvu.sexpr')
+    assert_list_equal(
+        sorted(ns.keys()), [
+            'Expression',
+            'ExpressionSyntaxError',
+            'IntExpression',
+            'InvalidExpression',
+            'ListExpression',
+            'StringExpression',
+            'Symbol',
+            'SymbolExpression'
+        ]
+    )
+
 # vim:ts=4 sts=4 sw=4 et
